#
# spec file for package tenmon
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} && 0%{?suse_version} < 1590
%global force_gcc_version 12
%endif

Name:           tenmon
Version:        20240816
Release:        1.3
Summary:        FITS and XISF image viewer, converter and indexer
License:        GPL-3.0-or-later
URL:            https://gitea.nouspiro.space/nou/tenmon/
Source:         https://gitea.nouspiro.space/nou/tenmon/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         use_system_libxisf.patch
# PATCH-FIX-UPSTREAM
Patch1:         fix-libxisf-include.patch
BuildRequires:  gcc%{?force_gcc_version}-c++ >= 12
BuildRequires:  libXISF-devel >= 0.2.12+git5.d00de20
BuildRequires:  pkgconfig
BuildRequires:  qt6-base-devel >= 6.2.0
BuildRequires:  pkgconfig(Qt6OpenGL)
BuildRequires:  pkgconfig(Qt6Qml)
BuildRequires:  pkgconfig(Qt6Sql)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libraw)
BuildRequires:  pkgconfig(wcslib)

%description
RAW/FITS/XISF image viewer with multithreaded image loading.
Features included, but not limited to:
* FITS 8, 16 bit integer and 32 bit float
* XISF 8, 16 bit integer and 32 bit float
* JPEG and PNG images
* NEF, CR2 and DNG raw files
* Using same stretch function as PixInsight
* OpenGL accelerated drawing
* Index and search FITS XISF header data
* Quick mark images and then copy/move marked files
* Convert FITS <-> XISF
* Convert FITS/XISF -> JPEG/PNG
* Image statistics mean, media, min, max

%prep
%autosetup -p1 -n %{name}

%build
export CFLAGS=$(echo "$CFLAGS -Wno-switch -Wno-catch-value")
export  CXXFLAGS=$(echo "$CXXFLAGS -Wno-switch -Wno-catch-value")
%cmake \
 -DRELEASE_BUILD=ON \
%if 0%{?force_gcc_version}
    -DCMAKE_CXX_COMPILER=%{_bindir}/g++-%{?force_gcc_version} \
%endif

%cmake_build

%install
%cmake_install

%files
%license LICENSE
%doc README
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/128x128
%dir %{_datadir}/icons/hicolor/128x128/apps
%dir %{_datadir}/icons/hicolor/64x64
%dir %{_datadir}/icons/hicolor/64x64/apps
%{_bindir}/tenmon
%{_datadir}/applications/space.nouspiro.tenmon.desktop
%{_datadir}/icons/hicolor/128x128/apps/space.nouspiro.tenmon.png
%{_datadir}/icons/hicolor/64x64/apps/space.nouspiro.tenmon.png
%{_datadir}/metainfo/space.nouspiro.tenmon.metainfo.xml

%changelog
* Fri Sep 13 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 20240816:
  * Remember auto stretch on load
  * Add support for FLOAT16 image downscale
  * Fix output path browse dialog path
  * Fix fromPlanaerSSE
  * Debayer fix on OpenGL ES
  * Use lcms2 for color profiles
* Wed Jul  3 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 20240617:
  * Add scripts
  * Small fixes
  * Fix some bugs in scripting
  * Fix text color in log
  * Batchprocessing improvments
  * Add FITSRecordModify for XISF files
  * Add modifing FITS records
  * Add compression parameters
  * Add convert function to script
  * Fix bug when saving color FITS/XISF files
- Add fix-libxisf-include.patch.
* Wed Jun 12 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 20240610:
  * Fix some bugs in scripting
  * Fix text color in log
  * Batchprocessing improvments
  * Add FITSRecordModify for XISF files
  * Add modifing FITS records
  * Add compression parameters
  * Add convert function to script
  * Fix bug when saving color FITS/XISF files
- Add fix-libxisf-include.patch.
* Wed Feb 14 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 20240201:
  * Fix metainfo
  * Add thumbnail quality to settings
  * Only degress should show negative sign
  * Limit image info to 1024 characters
  * Flip image according to ROWORDER
  * Fix some edge cases when stretch
  * Small optimization in resample
  * Add box resize algorithm
* Tue Jan  9 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 20240108:
  * Migrate to Qt6
  * Add nearest and bicubic filtering
  * Add slideshow
  * Don't skip images before they load
  * Add bayer mask selection
  * Additional work on batch processing
  * Increase number max preload images to 32
* Fri Nov 17 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 20231116:
  * Add scaling for float images that are out of 0.0-1.0 range
  * Optimize calculating stast for debayer
  * Better stretch non full range images like CR2
  * Made unlinked stretch white balancing
  * Make STF slider wider
  * Add tooltip with filenames
  * Support for unlinked stretch
  * Sum all channels histograms
  * Improve histogram for 8 bit images
  * Add histogram
  * Fix loading RAW files
  * Show stats for each channel
  * Update translations and help
* Thu Apr 20 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 20230419:
  * Fix assert lo < hi in std::clamp
  * Update metainfo
* Mon Apr 17 2023 Paolo Stivanin <info@paolostivanin.com>
- Initial OBS release.
- Add use_system_libxisf.patch.
